@@ -19,8 +19,10 @@ from .livemessage import LiveMessage
 
 import http.client as http
 import logging
+import platform
 import socket
 import ssl
+import time
 import xml.parsers.expat as expat
 
 
@@ -35,8 +37,6 @@ class TellstickLiveClient(object):
     SUBJECT_PONG = "pong"
     # <no parameters>
     SUBJECT_DISCONNECT = "disconnect"
-    # "callback"
-    SUBJECT_RELOAD = "reload"
 
     def __init__(self, public_key, private_key):
         super(TellstickLiveClient, self).__init__()
@@ -44,6 +44,8 @@ class TellstickLiveClient(object):
         self.public_key = public_key
         self.private_key = private_key
         self.hash_method = "sha1"
+        self.time_sent = 0
+        self.time_received = 0
 
     def ssl_context(self):
         context = ssl.SSLContext(ssl.PROTOCOL_TLSv1)
@@ -87,6 +89,8 @@ class TellstickLiveClient(object):
         sock.connect(address)
         ssl.match_hostname(sock.getpeercert(), address[0])
         self.socket = sock
+        self.time_sent = time.time()
+        self.time_received = self.time_sent
 
     def connect_to_first_available_server(self, **kwargs):
         for server in self.servers():
@@ -110,10 +114,12 @@ class TellstickLiveClient(object):
         data = envelope.serialize()
         logging.debug("Sending: %s", data)
         self.socket.write(data)
+        self.time_sent = time.time()
 
     def receive_message(self):
         data = self.socket.read(1024)
         logging.debug("Received: %s", data)
+        self.time_received = time.time()
 
         envelope = LiveMessage.deserialize(data)
         if not envelope.verify_signature(self.private_key, self.hash_method):
@@ -125,8 +131,18 @@ class TellstickLiveClient(object):
         message = LiveMessage("Register")
         message.append({'key': self.public_key, 'uuid': uuid,
                         'hash': self.hash_method})
+        os = platform.system().lower()
+        if os == "linux":
+            os_version = platform.linux_distribution()[0]
+        elif os == "darwin":
+            os = "macosx"
+            os_version = platform.mac_ver()[0]
+        elif os == "windows":
+            os_version = platform.win32_ver()[0]
+        else:
+            os_version = ""
         message.append({'protocol': 2, 'version': str(version),
-                        'os': "linux", 'os-version': "unknown"})
+                        'os': os, 'os-version': os_version.lower()})
         self.send_message(message)
 
     def ping(self):
